Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(214)

Unified Diff: webkit/browser/fileapi/file_system_context.h

Issue 18344013: fileapi: Rename FileSystemMountProvider to FileSystemBackend (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: address comments Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/browser/fileapi/file_system_context.h
diff --git a/webkit/browser/fileapi/file_system_context.h b/webkit/browser/fileapi/file_system_context.h
index 21d48be36630dc3c52de8de9e29cbd957bd6cf43..cab51827599ceb5d2d2ac1dfaa56ab464e2f7b62 100644
--- a/webkit/browser/fileapi/file_system_context.h
+++ b/webkit/browser/fileapi/file_system_context.h
@@ -48,20 +48,20 @@ namespace fileapi {
class AsyncFileUtil;
class CopyOrMoveFileValidatorFactory;
-class ExternalFileSystemMountPointProvider;
+class ExternalFileSystemBackend;
class ExternalMountPoints;
class FileStreamWriter;
class FileSystemFileUtil;
-class FileSystemMountPointProvider;
+class FileSystemBackend;
class FileSystemOperation;
class FileSystemOperationRunner;
class FileSystemOptions;
class FileSystemQuotaUtil;
class FileSystemTaskRunners;
class FileSystemURL;
-class IsolatedMountPointProvider;
+class IsolatedFileSystemBackend;
class MountPoints;
-class SandboxMountPointProvider;
+class SandboxFileSystemBackend;
struct DefaultContextDeleter;
@@ -102,7 +102,7 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
ExternalMountPoints* external_mount_points,
quota::SpecialStoragePolicy* special_storage_policy,
quota::QuotaManagerProxy* quota_manager_proxy,
- ScopedVector<FileSystemMountPointProvider> additional_providers,
+ ScopedVector<FileSystemBackend> additional_providers,
kinuko 2013/07/04 08:44:35 additional_providers -> additional_backends
satorux1 2013/07/05 04:47:57 Done.
const base::FilePath& partition_path,
const FileSystemOptions& options);
@@ -134,7 +134,7 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
// Returns the mount point provider instance for the given |type|.
kinuko 2013/07/04 08:44:35 Returns the file system backend
satorux1 2013/07/05 04:47:57 Done.
// This may return NULL if it is given an invalid or unsupported filesystem
// type.
- FileSystemMountPointProvider* GetMountPointProvider(
+ FileSystemBackend* GetMountPointProvider(
kinuko 2013/07/04 08:44:35 Can we rename this to GetMountPointProvider -> Get
satorux1 2013/07/05 04:47:57 Done.
FileSystemType type) const;
// Returns true for sandboxed filesystems. Currently this does
@@ -150,10 +150,10 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
// Returns all registered filesystem types.
void GetFileSystemTypes(std::vector<FileSystemType>* types) const;
// Returns a FileSystemMountPointProvider instance for external filesystem
// type, which is used only by chromeos for now. This is equivalent to
// calling GetMountPointProvider(kFileSystemTypeExternal).
kinuko 2013/07/04 08:44:35 GetMountPointProvider -> GetFileSystemBackend
satorux1 2013/07/05 04:47:57 Done.
- ExternalFileSystemMountPointProvider* external_provider() const;
+ ExternalFileSystemBackend* external_provider() const;
// Used for OpenFileSystem.
typedef base::Callback<void(base::PlatformFileError result,
@@ -236,7 +236,7 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
#endif
private:
- typedef std::map<FileSystemType, FileSystemMountPointProvider*>
+ typedef std::map<FileSystemType, FileSystemBackend*>
MountPointProviderMap;
kinuko 2013/07/04 08:44:35 MountPointProviderMap -> FileSystemBackendMap
satorux1 2013/07/05 04:47:57 Done.
// For CreateFileSystemOperation.
@@ -276,23 +276,23 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
// For initial provider_map construction. This must be called only from
kinuko 2013/07/04 08:44:35 provider_map -> backend_map
satorux1 2013/07/05 04:47:57 Done.
// the constructor.
- void RegisterMountPointProvider(FileSystemMountPointProvider* provider);
+ void RegisterMountPointProvider(FileSystemBackend* provider);
kinuko 2013/07/04 08:44:35 RegisterBackend
satorux1 2013/07/05 04:47:57 Done.
- // Returns a FileSystemMountPointProvider, used only by test code.
- SandboxMountPointProvider* sandbox_provider() const {
- return sandbox_provider_.get();
+ // Returns a FileSystemBackend, used only by test code.
+ SandboxFileSystemBackend* sandbox_provider() const {
kinuko 2013/07/04 08:44:35 Can we rename this too to sandbox_backend()?
satorux1 2013/07/05 04:47:57 Done.
+ return sandbox_backend_.get();
}
scoped_ptr<FileSystemTaskRunners> task_runners_;
scoped_refptr<quota::QuotaManagerProxy> quota_manager_proxy_;
- // Regular mount point providers.
- scoped_ptr<SandboxMountPointProvider> sandbox_provider_;
- scoped_ptr<IsolatedMountPointProvider> isolated_provider_;
+ // Regular file system backends.
+ scoped_ptr<SandboxFileSystemBackend> sandbox_backend_;
+ scoped_ptr<IsolatedFileSystemBackend> isolated_backend_;
- // Additional mount point providers.
- ScopedVector<FileSystemMountPointProvider> additional_providers_;
+ // Additional file system backends.
+ ScopedVector<FileSystemBackend> additional_backends_;
// Registered mount point providers.
kinuko 2013/07/04 08:44:35 mount point providers -> file system backends
satorux1 2013/07/05 04:47:57 Done.
@@ -150,10 +150,10 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemContext
// Returns all registered filesystem types.
void GetFileSystemTypes(std::vector<FileSystemType>* types) const;
- // Returns a FileSystemMountPointProvider instance for external filesystem
+ // Returns a FileSystemBackend instance for external filesystem
// type, which is used only by chromeos for now. This is equivalent to
// calling GetMountPointProvider(kFileSystemTypeExternal).
// The map must be constructed in the constructor since it can be accessed

Powered by Google App Engine
This is Rietveld 408576698